@@ -3,155 +3,206 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Behavior</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Automatically save documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Restore window geometry</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Open external links in ReText window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="169"/>
+        <location filename="../ReText/config.py" line="184"/>
         <source>Editor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Highlight current line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Show line numbers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Tab key inserts spaces</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Tabulation width</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Icon theme name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Stylesheet file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="151"/>
+        <location filename="../ReText/config.py" line="166"/>
         <source>Help</source>
         <translation type="unfinished">Abi</translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Enable synchronized scrolling for Markdown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Draw vertical line at column</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Automatically open last documents on startup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="80"/>
+        <location filename="../ReText/config.py" line="91"/>
         <source>Using configuration file at:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Number of recent documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Default preview state</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Line numbers are relative to current line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Enable soft wrap</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Show document stats</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Hide toolbar</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Hide tabs bar when there is only one tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="97"/>
+        <location filename="../ReText/config.py" line="109"/>
         <source>Show full path in window title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="170"/>
+        <location filename="../ReText/config.py" line="185"/>
         <source>Live preview</source>
         <translation type="unfinished">Aktiivne eelvaade</translation>
     </message>
     <message>
-        <location filename="../ReText/config.py" line="171"/>
+        <location filename="../ReText/config.py" line="186"/>
         <source>Normal preview</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Ordered list mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Show directory tree</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Working directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="191"/>
+        <source>Disabled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="192"/>
+        <source>Cursor Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="193"/>
+        <source>Wrapped Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="198"/>
+        <source>Increment</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="199"/>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DirectorySelectButton</name>
+    <message>
+        <location filename="../ReText/config.py" line="60"/>
+        <source>Select directory to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileDialogButton</name>
+    <message>
+        <location filename="../ReText/config.py" line="35"/>
+        <source>(none)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="../ReText/config.py" line="35"/>
-        <source>(none)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="42"/>
+        <location filename="../ReText/config.py" line="52"/>
         <source>Select file to open</source>
         <translation type="unfinished"></translation>
     </message>
@@ -203,17 +254,17 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="../ReText/editor.py" line="391"/>
+        <location filename="../ReText/editor.py" line="460"/>
         <source>Save image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/editor.py" line="391"/>
+        <location filename="../ReText/editor.py" line="460"/>
         <source>Images (*.png *.jpg)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/editor.py" line="212"/>
+        <location filename="../ReText/editor.py" line="248"/>
         <source>Add to dictionary</source>
         <translation type="unfinished"></translation>
     </message>
@@ -221,34 +272,34 @@
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="../ReText/tab.py" line="184"/>
+        <location filename="../ReText/tab.py" line="185"/>
         <source>New document</source>
         <translation>Uus dokument</translation>
     </message>
     <message>
-        <location filename="../ReText/tab.py" line="189"/>
+        <location filename="../ReText/tab.py" line="190"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/tab.py" line="478"/>
+        <location filename="../ReText/tab.py" line="497"/>
         <source>Create missing file?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/tab.py" line="478"/>
+        <location filename="../ReText/tab.py" line="497"/>
         <source>The file &apos;%s&apos; does not exist.
 
 Do you want to create it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/tab.py" line="511"/>
+        <location filename="../ReText/tab.py" line="530"/>
         <source>File could not be created</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/tab.py" line="511"/>
+        <location filename="../ReText/tab.py" line="530"/>
         <source>Could not create file &apos;%s&apos;: %s</source>
         <translation type="unfinished"></translation>
     </message>
@@ -256,508 +307,503 @@ Do you want to create it?</source>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="../ReText/window.py" line="82"/>
+        <location filename="../ReText/window.py" line="94"/>
         <source>File toolbar</source>
         <translation>Faili tööriistariba</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="84"/>
+        <location filename="../ReText/window.py" line="96"/>
         <source>Edit toolbar</source>
         <translation>Muuda tööriistariba</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="86"/>
+        <location filename="../ReText/window.py" line="98"/>
         <source>Search toolbar</source>
         <translation>Otsingu tööriistariba</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="90"/>
+        <location filename="../ReText/window.py" line="102"/>
         <source>New</source>
         <translation>Uus</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="93"/>
+        <location filename="../ReText/window.py" line="104"/>
         <source>Open</source>
         <translation>Ava</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="102"/>
+        <location filename="../ReText/window.py" line="112"/>
         <source>Save</source>
         <translation>Salvesta</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="106"/>
+        <location filename="../ReText/window.py" line="115"/>
         <source>Save as</source>
         <translation>Salvesta kui...</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="114"/>
+        <location filename="../ReText/window.py" line="123"/>
         <source>Print</source>
         <translation>Prindi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="117"/>
+        <location filename="../ReText/window.py" line="125"/>
         <source>Print preview</source>
         <translation>Printimise eelvaade</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="119"/>
+        <location filename="../ReText/window.py" line="127"/>
         <source>View HTML code</source>
         <translation>Vaata HTML koodi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="124"/>
+        <location filename="../ReText/window.py" line="132"/>
         <source>Find text</source>
         <translation>Leia tekst</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="129"/>
+        <location filename="../ReText/window.py" line="137"/>
         <source>Preview</source>
         <translation>Eelvaade</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="139"/>
+        <location filename="../ReText/window.py" line="147"/>
         <source>Live preview</source>
         <translation>Aktiivne eelvaade</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="157"/>
+        <location filename="../ReText/window.py" line="164"/>
         <source>Fullscreen mode</source>
         <translation>Täisekraani režiim</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="168"/>
+        <location filename="../ReText/window.py" line="174"/>
         <source>Quit</source>
         <translation>Välju</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="171"/>
+        <location filename="../ReText/window.py" line="177"/>
         <source>Undo</source>
         <translation>Võta tagasi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="173"/>
+        <location filename="../ReText/window.py" line="179"/>
         <source>Redo</source>
         <translation>Korda</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="175"/>
+        <location filename="../ReText/window.py" line="181"/>
         <source>Copy</source>
         <translation>Kopeeri</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="177"/>
+        <location filename="../ReText/window.py" line="183"/>
         <source>Cut</source>
         <translation>Lõika</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="179"/>
+        <location filename="../ReText/window.py" line="185"/>
         <source>Paste</source>
         <translation>Aseta</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="195"/>
+        <location filename="../ReText/window.py" line="200"/>
         <source>Enable</source>
         <translation>Luba</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="196"/>
+        <location filename="../ReText/window.py" line="201"/>
         <source>Set locale</source>
         <translation>Sea regioon</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="197"/>
+        <location filename="../ReText/window.py" line="202"/>
         <source>Use WebKit renderer</source>
         <translation>Kasuta WebKit renderdajat</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="208"/>
+        <location filename="../ReText/window.py" line="213"/>
         <source>Next</source>
         <translation>Järgmine</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="210"/>
+        <location filename="../ReText/window.py" line="215"/>
         <source>Previous</source>
         <translation>Eelmine</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="222"/>
+        <location filename="../ReText/window.py" line="226"/>
         <source>Get help online</source>
         <translation>Saa abi internetist</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="223"/>
+        <location filename="../ReText/window.py" line="227"/>
         <source>About ReText</source>
         <translation>ReText kohta</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="226"/>
+        <location filename="../ReText/window.py" line="230"/>
         <source>About Qt</source>
         <translation>Qt kohta</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="241"/>
+        <location filename="../ReText/window.py" line="245"/>
         <source>Bold</source>
         <translation>Rasvane</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="243"/>
+        <location filename="../ReText/window.py" line="247"/>
         <source>Italic</source>
         <translation>Kaldu</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="245"/>
+        <location filename="../ReText/window.py" line="249"/>
         <source>Underline</source>
         <translation>Allajoonitud</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="258"/>
+        <location filename="../ReText/window.py" line="265"/>
         <source>Symbols</source>
         <translation>Sümbolid</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="263"/>
-        <source>File</source>
-        <translation>Fail</translation>
+        <location filename="../ReText/window.py" line="270"/>
+        <source>&amp;File</source>
+        <translation>&amp;Fail</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="264"/>
-        <source>Edit</source>
-        <translation>Muuda</translation>
+        <location filename="../ReText/window.py" line="271"/>
+        <source>&amp;Edit</source>
+        <translation>&amp;Muuda</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="265"/>
-        <source>Help</source>
-        <translation>Abi</translation>
+        <location filename="../ReText/window.py" line="272"/>
+        <source>&amp;Help</source>
+        <translation>&amp;Abi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="268"/>
+        <location filename="../ReText/window.py" line="275"/>
         <source>Open recent</source>
         <translation>Ava hiljutine</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="281"/>
+        <location filename="../ReText/window.py" line="288"/>
         <source>Export</source>
         <translation>Ekspordi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="306"/>
+        <location filename="../ReText/window.py" line="313"/>
         <source>Spell check</source>
         <translation>Õigekirjakontroll</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="318"/>
+        <location filename="../ReText/window.py" line="325"/>
         <source>Formatting</source>
         <translation>Vormindus</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="360"/>
+        <location filename="../ReText/window.py" line="372"/>
         <source>Search</source>
         <translation>Otsi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="365"/>
+        <location filename="../ReText/window.py" line="377"/>
         <source>Case sensitively</source>
         <translation>Tõstutundeliselt</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="526"/>
+        <location filename="../ReText/window.py" line="567"/>
         <source>New document</source>
         <translation>Uus dokument</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="714"/>
+        <location filename="../ReText/window.py" line="755"/>
         <source>Please, save the file somewhere.</source>
         <translation>Palun salvesta fail kuhugi.</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="207"/>
+        <location filename="../ReText/window.py" line="212"/>
         <source>Show directory</source>
         <translation>Näita kataloogi</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="830"/>
+        <location filename="../ReText/window.py" line="871"/>
         <source>Select one or several files to open</source>
         <translation>Vali avamiseks üks või mitu faili</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1248"/>
+        <location filename="../ReText/window.py" line="1289"/>
         <source>Supported files</source>
         <translation>Toetatud failid</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1248"/>
+        <location filename="../ReText/window.py" line="1289"/>
         <source>All files (*)</source>
         <translation>Kõik failid (*)</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="892"/>
+        <location filename="../ReText/window.py" line="933"/>
         <source>Plain text (*.txt)</source>
         <translation>Tavaline tekst (*.txt)</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="970"/>
+        <location filename="../ReText/window.py" line="1011"/>
         <source>Save file</source>
         <translation>Salvesta fail</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="938"/>
+        <location filename="../ReText/window.py" line="979"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Ei saa faili salvestada, kuna see fail on ainult lugemiseks!</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1001"/>
         <source>Export document to ODT</source>
         <translation>Ekspordi dokument ODT formaati</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1001"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument tekstifailid (.*odt)</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="970"/>
+        <location filename="../ReText/window.py" line="1011"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML failid (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1019"/>
+        <location filename="../ReText/window.py" line="1060"/>
         <source>Export document to PDF</source>
         <translation>Ekspordi dokument PDF&apos;ina</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1019"/>
+        <location filename="../ReText/window.py" line="1060"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF failid (*.pdf)</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1046"/>
+        <location filename="../ReText/window.py" line="1087"/>
         <source>Print document</source>
         <translation>Prindi dokument</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1069"/>
+        <location filename="../ReText/window.py" line="1110"/>
         <source>Export document</source>
         <translation>Ekspordi dokument</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1090"/>
+        <location filename="../ReText/window.py" line="1131"/>
         <source>Failed to execute the command:</source>
         <translation>Järgmise käsu täitmine ebaõnnestus:</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1210"/>
+        <location filename="../ReText/window.py" line="1251"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Dokumenti on muudetud.
 Soovid salvestada oma muudatused?</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1238"/>
+        <location filename="../ReText/window.py" line="1279"/>
         <source>HTML code</source>
         <translation>HTML kood</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1266"/>
+        <location filename="../ReText/window.py" line="1307"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Lihtne aga võimas Markdown ja reStructuredText redaktor</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1266"/>
+        <location filename="../ReText/window.py" line="1307"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1266"/>
-        <source>Website</source>
-        <translation>Veebileht</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1266"/>
+        <location filename="../ReText/window.py" line="1307"/>
         <source>Markdown syntax</source>
         <translation>Markdown süntaks</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1266"/>
+        <location filename="../ReText/window.py" line="1307"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText süntaks</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="895"/>
+        <location filename="../ReText/window.py" line="936"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s failid</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="315"/>
+        <location filename="../ReText/window.py" line="322"/>
         <source>Default markup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="630"/>
+        <location filename="../ReText/window.py" line="671"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="96"/>
+        <location filename="../ReText/window.py" line="106"/>
         <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="869"/>
+        <location filename="../ReText/window.py" line="910"/>
         <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1190"/>
+        <location filename="../ReText/window.py" line="1231"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="108"/>
+        <location filename="../ReText/window.py" line="117"/>
         <source>Next tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="110"/>
+        <location filename="../ReText/window.py" line="119"/>
         <source>Previous tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="146"/>
+        <location filename="../ReText/window.py" line="153"/>
         <source>Table editing mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="152"/>
+        <location filename="../ReText/window.py" line="159"/>
         <source>FakeVim mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1173"/>
+        <location filename="../ReText/window.py" line="1214"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1181"/>
+        <location filename="../ReText/window.py" line="1222"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1186"/>
+        <location filename="../ReText/window.py" line="1227"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="120"/>
+        <location filename="../ReText/window.py" line="128"/>
         <source>Change editor font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="122"/>
+        <location filename="../ReText/window.py" line="130"/>
         <source>Change preview font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1266"/>
+        <location filename="../ReText/window.py" line="1307"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="218"/>
+        <location filename="../ReText/window.py" line="222"/>
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1131"/>
+        <location filename="../ReText/window.py" line="1172"/>
         <source>Alt text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1132"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1132"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>Link text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="212"/>
+        <location filename="../ReText/window.py" line="217"/>
         <source>Replace</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="214"/>
+        <location filename="../ReText/window.py" line="219"/>
         <source>Replace all</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="363"/>
+        <location filename="../ReText/window.py" line="375"/>
         <source>Replace with</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="915"/>
+        <location filename="../ReText/window.py" line="956"/>
         <source>Cannot save to file which is open in another tab!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="202"/>
+        <location filename="../ReText/window.py" line="207"/>
         <source>Use WebEngine (Chromium) renderer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="112"/>
+        <location filename="../ReText/window.py" line="121"/>
         <source>Close tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="678"/>
+        <location filename="../ReText/window.py" line="719"/>
         <source>Go to line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="144"/>
+        <location filename="../ReText/window.py" line="151"/>
         <source>Insert table</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="149"/>
+        <location filename="../ReText/window.py" line="156"/>
         <source>Insert images by file path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="181"/>
+        <location filename="../ReText/window.py" line="187"/>
         <source>Paste image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="183"/>
+        <location filename="../ReText/window.py" line="189"/>
         <source>Move line up</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="185"/>
+        <location filename="../ReText/window.py" line="191"/>
         <source>Move line down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="678"/>
+        <location filename="../ReText/window.py" line="719"/>
         <source>Type the line number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="993"/>
+        <location filename="../ReText/window.py" line="1034"/>
         <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1248"/>
+        <location filename="../ReText/window.py" line="1289"/>
         <source>Select one or several images to open</source>
         <translation type="unfinished"></translation>
     </message>
@@ -765,7 +811,7 @@ Do you want to reload the file (this will discard all your changes)?
 <context>
     <name>TextInfoArea</name>
     <message>
-        <location filename="../ReText/editor.py" line="582"/>
+        <location filename="../ReText/editor.py" line="651"/>
         <source>%d w | %d a | %d c</source>
         <comment>count of words, alphanumeric characters, all characters</comment>
         <translation type="unfinished"></translation>
@@ -774,17 +820,17 @@ Do you want to reload the file (this will discard all your changes)?
 <context>
     <name>main</name>
     <message>
-        <location filename="../ReText/__main__.py" line="77"/>
+        <location filename="../ReText/__main__.py" line="88"/>
         <source>Open the files in preview mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/__main__.py" line="79"/>
+        <location filename="../ReText/__main__.py" line="90"/>
         <source>Create a new window even if there is an existing one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/__main__.py" line="83"/>
+        <location filename="../ReText/__main__.py" line="94"/>
         <source>List of files to open</source>
         <translation type="unfinished"></translation>
     </message>
