@@ -1,5 +1,5 @@
 # This file is part of ReText
-# Copyright: 2014-2015 Dmitry Shachnev
+# Copyright: 2014-2021 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,23 +24,23 @@ from PyQt5.QtGui import QColor, QFont
 from PyQt5.QtWidgets import QApplication
 from ReText import readListFromSettings, writeListToSettings, \
  readFromSettings, writeToSettings
-from ReText.highlighter import colorScheme, updateColorScheme
+from ReText.editor import getColor, updateColorScheme
 
 # For this particular test, QCoreApplication is enough. However, we should
 # only have one QCoreApplication instance for all tests in a process. As
 # other tests need QApplication, we should not create a bare QCoreApplication
 # here. Also, keep a reference so it is not garbage collected.
-QApplication.setAttribute(Qt.AA_ShareOpenGLContexts)
+QApplication.setAttribute(Qt.ApplicationAttribute.AA_ShareOpenGLContexts)
 app = QApplication.instance() or QApplication(sys.argv)
 
 class TestSettings(unittest.TestCase):
 	def setUp(self):
 		self.tempFile = tempfile.NamedTemporaryFile(prefix='retext-', suffix='.ini')
 		baseName = splitext(basename(self.tempFile.name))[0]
-		QSettings.setPath(QSettings.IniFormat, QSettings.UserScope,
+		QSettings.setPath(QSettings.Format.IniFormat, QSettings.Scope.UserScope,
 		                  dirname(self.tempFile.name))
-		self.settings = QSettings(QSettings.IniFormat,
-		                          QSettings.UserScope, baseName)
+		self.settings = QSettings(QSettings.Format.IniFormat,
+		                          QSettings.Scope.UserScope, baseName)
 
 	def tearDown(self):
 		del self.settings # this should be deleted before tempFile
@@ -84,10 +84,10 @@ class TestSettings(unittest.TestCase):
 		self.settings.setValue('ColorScheme/htmlSymbols', '#ff8800')
 		self.settings.setValue('ColorScheme/htmlComments', '#abc')
 		updateColorScheme(self.settings)
-		self.assertEqual(colorScheme['htmlTags'], QColor(0x00, 0x80, 0x00))
-		self.assertEqual(colorScheme['htmlSymbols'], QColor(0xff, 0x88, 0x00))
-		self.assertEqual(colorScheme['htmlStrings'], Qt.darkYellow) # default
-		self.assertEqual(colorScheme['htmlComments'], QColor(0xaa, 0xbb, 0xcc))
+		self.assertEqual(getColor('htmlTags'), QColor(0x00, 0x80, 0x00))
+		self.assertEqual(getColor('htmlSymbols'), QColor(0xff, 0x88, 0x00))
+		self.assertEqual(getColor('htmlStrings'), Qt.GlobalColor.darkYellow) # default
+		self.assertEqual(getColor('htmlComments'), QColor(0xaa, 0xbb, 0xcc))
 
 if __name__ == '__main__':
 	unittest.main()
